<?php

namespace Cushbu\Artwork\Providers;

use Illuminate\Support\ServiceProvider;

class ArtworkServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'artwork');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'artwork');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('artwork', function ($app) {
            return $this->app->make('Cushbu\Artwork\Artwork');
        });

        // Bind Artwork to repository
        $this->app->bind(
            \Cushbu\Artwork\Interfaces\ArtworkRepositoryInterface::class,
            \Cushbu\Artwork\Repositories\Eloquent\ArtworkRepository::class
        );

        $this->app->register(\Cushbu\Artwork\Providers\AuthServiceProvider::class);
        $this->app->register(\Cushbu\Artwork\Providers\EventServiceProvider::class);
        $this->app->register(\Cushbu\Artwork\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['artwork'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/artwork.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/artwork')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/artwork')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
